from distutils.core import setup

setup(
    name='baizhanMath123',#对外我们模块的名字
    version='1.0',#版本号
    description='这是第一个对外发布的模块，测试哦',#描述
    author='zufei',#作者
    author_email='1160986076@qq.com',
    py_modules=['baizhanMath123.demo1','baizhanMath123.demo2']#要发布的模
)